@@ -8,6 +8,10 @@
 #![allow(clippy::string_lit_as_bytes)]
 // Public items exportedby this crate should match the C style
 #![allow(clippy::upper_case_acronyms)]
+// Suppress warnings from bindgen-generated code
+// Remove on resolution of
+// https://github.com/rust-lang/rust-bindgen/issues/1651
+#![allow(deref_nullptr)]
 
 // For supported targets: use the generated and committed bindings.
 #[cfg(all(
@@ -70,6 +74,16 @@ include!(concat!(
     "/src/bindings/x86_64-unknown-darwin.rs"
 ));
 
+#[cfg(all(
+    not(feature = "generate-bindings"),
+    target_arch = "x86_64",
+    target_os = "windows"
+))]
+include!(concat!(
+    env!("CARGO_MANIFEST_DIR"),
+    "/src/bindings/x86_64-windows.rs"
+));
+
 // If the "generate-bindings" feature is on, use the generated bindings.
 #[cfg(feature = "generate-bindings")]
 include!(concat!(env!("OUT_DIR"), "/pkcs11_bindings.rs"));
